@@ -1,7 +1,4 @@
-extern crate m3u8_rs;
-extern crate nom;
-
-use m3u8_rs::playlist::Playlist;
+use m3u8_rs::Playlist;
 use std::io::Read;
 
 fn main() {
@@ -12,7 +9,7 @@ fn main() {
     let parsed = m3u8_rs::parse_playlist(&bytes);
 
     let playlist = match parsed {
-        Result::Ok((i, playlist)) => playlist,
+        Result::Ok((_i, playlist)) => playlist,
         Result::Err(e) => panic!("Parsing error: \n{}", e),
     };
 
@@ -22,6 +19,7 @@ fn main() {
     }
 }
 
+#[allow(unused)]
 fn main_alt() {
     let mut file = std::fs::File::open("playlist.m3u8").unwrap();
     let mut bytes: Vec<u8> = Vec::new();
@@ -30,8 +28,8 @@ fn main_alt() {
     let parsed = m3u8_rs::parse_playlist(&bytes);
 
     match parsed {
-        Result::Ok((i, Playlist::MasterPlaylist(pl))) => println!("Master playlist:\n{:?}", pl),
-        Result::Ok((i, Playlist::MediaPlaylist(pl))) => println!("Media playlist:\n{:?}", pl),
+        Result::Ok((_i, Playlist::MasterPlaylist(pl))) => println!("Master playlist:\n{:?}", pl),
+        Result::Ok((_i, Playlist::MediaPlaylist(pl))) => println!("Media playlist:\n{:?}", pl),
         Result::Err(e) => panic!("Parsing error: \n{}", e),
     }
 }
