@@ -42,6 +42,8 @@ use std::string;
 /// }
 /// ```
 pub fn parse_playlist(input: &[u8]) -> IResult<&[u8], Playlist> {
+    m3u_tag(input)?;
+
     match is_master_playlist(input) {
         true => map(parse_master_playlist, Playlist::MasterPlaylist)(input),
         false => map(parse_media_playlist, Playlist::MediaPlaylist)(input),
@@ -135,6 +137,7 @@ pub fn is_master_playlist(input: &[u8]) -> bool {
 /// - Some(true, tagstring): Line contains a master playlist tag
 /// - Some(false, tagstring): Line contains a media playlist tag
 fn contains_master_tag(input: &[u8]) -> Option<(bool, String)> {
+    let (input, _) = m3u_tag(input).ok()?;
     let mut is_master_opt = None;
     let mut current_input: &[u8] = input;
 
@@ -340,8 +343,8 @@ enum MediaPlaylistTag {
     Version(usize),
     Segment(SegmentTag),
     TargetDuration(f32),
-    MediaSequence(i32),
-    DiscontinuitySequence(i32),
+    MediaSequence(u64),
+    DiscontinuitySequence(u64),
     EndList,
     PlaylistType(MediaPlaylistType),
     IFramesOnly,
@@ -641,11 +644,11 @@ fn consume_line(i: &[u8]) -> IResult<&[u8], String> {
     )(i)
 }
 
-fn number(i: &[u8]) -> IResult<&[u8], i32> {
+fn number(i: &[u8]) -> IResult<&[u8], u64> {
     map_res(take_while1(is_digit), |s| {
         // Can't fail because we validated it above already
         let s = str::from_utf8(s).unwrap();
-        str::parse::<i32>(s)
+        str::parse::<u64>(s)
     })(i)
 }
 
